summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFrédéric Desbiens <[email protected]>2025-09-28 22:53:58 +0100
committerFrédéric Desbiens <[email protected]>2025-09-28 22:53:58 +0100
commitb8530b59ebc1266ac2b0808e9b51e25dc656c88d (patch)
tree31d83d73aa1a1da906236c72d8e097cd2268771c
parent1f59529034b046dbf4f67f4b946cdf64e9a68d0a (diff)
Added missing check for TX_QUEUE_MESSAGE_MAX_SIZE.
-rw-r--r--common_smp/src/txe_queue_create.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/common_smp/src/txe_queue_create.c b/common_smp/src/txe_queue_create.c
index 68d3540a..82a7b53c 100644
--- a/common_smp/src/txe_queue_create.c
+++ b/common_smp/src/txe_queue_create.c
@@ -178,8 +178,8 @@ TX_THREAD *thread_ptr;
status = TX_SIZE_ERROR;
}
- /* Check for an invalid message size - greater than 16. */
- else if (message_size > TX_16_ULONG)
+ /* Check for an invalid message sizegreater than TX_QUEUE_MESSAGE_MAX_SIZE 16 by default. */
+ else if (message_size > TX_QUEUE_MESSAGE_MAX_SIZE)
{
/* Invalid message size specified. */